Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobeฎ PDF format. The Adobeฎ Readerฎ is a free download. |
| Rows per Page

223 documents were found matching the selected criteria.
Page: [ 1] 2 3 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
State v. Graham | 13CA010489 | minor traffic violation turning violation R.C. 4511.36 practicable reasonable suspicion | Hensal | 7/28/2014 | 2014-Ohio-3283
State v. Buchanan | 13CA0041-M | motion to suppress, reasonable suspicion, methamphetamine, detention, seizure, drug dog | Belfance | 7/28/2014 | 2014-Ohio-3282
State v. Pope | 26928, 27096 | unclassified felony, postrelease control, Crim.R.11(C)(2)(a) | Moore | 7/23/2014 | 2014-Ohio-3212
State v. Crumpler | 26763 | forfeiture, R.C. Chapter 2981, Eastley v. Volkman, sufficiency, manifest weight, standard of review | Belfance | 7/23/2014 | 2014-Ohio-3211
Wilson | 12CA010263 | OVI - impairment - actual driving ability - chemical test refusal - R.C. 2945.75 - verdict forms | Carr | 7/21/2014 | 2014-Ohio-3182
Matus v. Merrill | 13CA010468 | doctrine of acquiescence of title weighing evidence on summary judgment adverse possession | Whitmore | 7/21/2014 | 2014-Ohio-3181
In re R.L. | 27214, 27233 | permanent custody, termination of parental rights, cannot or should not be placed with a parent, best interest of the child, six-month extension of temporary custody, substantial compliance with a case plan. | Belfance | 7/16/2014 | 2014-Ohio-3117
Hubiak v. Ohio Family Practice Ctr. | 26949 | Civ.R. 12(B), Civ.R. 12(C), improper service, waiver, application of amended rules | Celebrezze | 7/16/2014 | 2014-Ohio-3116
Giusti v. Felten | 26611, 26695 | jury challenge for cause, R.C. 2323.51, Civ.R.11 | Moorel | 7/16/2014 | 2014-Ohio-3115
Blinn v. Balint | 26733 | expert testimony, Evid.R. 703, Evid.R. 705, Evid.R. 702(C) | Hensal | 7/16/2014 | 2014-Ohio-3114
Taylor v. Uhl | 13CA010441 | summary judgment, Civ.R. 56(C), promissory note, negotiable instrument, consideration, gift, R.C. 1303.03(A), R.C. 1303.36(A), R.C. 1303.35(A), R.C. 1303.69(A) | Moore | 7/14/2014 | 2014-Ohio-3090
State v. Poore | 13CA0043 | sufficient evidence, petty theft, R.C. 2913.02 | Moore | 7/14/2014 | 2014-Ohio-3089
Drushal | 13CA0028 | Motion to Suppress, Exclusionary Rule, Mistake of Law | Moore | 7/14/2014 | 2014-Ohio-3088
State v. Flowers | 12CA010295 | Evid.R. 704, R.C.2907.03(A)(2) | Moore | 7/14/2014 | 2014-Ohio-3087
State v. Thomas | 26893 | aggravated vehicular homicide OVI sufficiency manifest weight- lay witness testimony Evid.R. 701 juror misconduct prejudice | Carr | 6/30/2014 | 2014-Ohio-2920
Bear v. Bear | 26810 | amendment to complaint, Civ.R. 15(A), summary judgment, Civ.R. 56, statute of limitations, R.C. 2305.09, Civ.R. 12(B)(6), Civ.R. 9(B), plead fraud with particularity | Hensal | 6/30/2014 | 2014-Ohio-2919
State v. Dopart | 13CA010486 | pretrial diversion program statutory authority separation of powers prosecutor trial court dismissal indictment | Carr | 6/30/2014 | 2014-Ohio-2901
Wysocki v. Oberlin Police Dept. | 13CA010437 | summary judgment, Civ.R. 56(C), 18 U.S.C. 921(g)(9); 18 U.S.C. 921(a)(33)(A)(ii) | Hensal | 6/30/2014 | 2014-Ohio-2869
CitiMortgage, Inc. v. Uhl | 13CA0014 | foreclosure standing invoke jurisdiction sufficient personal stake time of commencement of the action summary judgment dismiss | Carr | 6/30/2014 | 2014-Ohio-2868
State v. Ross | 26694 | murder felony murder asphyxiation strangulation double jeopardy mistrial motion to perfect verdict forms tainted verdicts statute of limitations tolling same conduct other acts evidence identity behavioral fingerprint | Whitmore | 6/30/2014 | 2014-Ohio-2867
State v. Richey | 13CA0031 | sufficiency, R.C. 2913.02, petty theft | Hensal | 6/30/2014 | 2014-Ohio-2866
State v. Purvis | 13CA0019 | States appeal, motion to suppress, consensual encounter | Belfance | 6/30/2014 | 2014-Ohio-2865
State v. Pope | 13CA0031-M | misdemeanor sentencing presumption of regularity App.R.3 jurisdiction | Whitmore | 6/30/2014 | 2014-Ohio-2864
State v. Perrymond | 13CA0046-M | confidential informant, plain error, forfeiture, manifest weight, witness credibility, Fifth Amendment, Crim.R. 52 | Hensal | 6/30/2014 | 2014-Ohio-2863
Patton v. Hickling-Patton | 13CA0071-M | spousal support, child support, custodial parent, extreme cruelty, gross neglect | Hensal | 6/30/2014 | 2014-Ohio-2862
McDonald v. McDonald | 13CA010341 | R.C. 3109.04, modification of parental rights, standard parenting time order, abuse of discretion | Hensal | 6/30/2014 | 2014-Ohio-2861
Matrix Acquisitions, L.L.C. v. Manley | 27191 | summary judgment, affidavit, personal knowledge, real party in interest, standing, statute of limitations, waiver | Hensal | 6/30/2014 | 2014-Ohio-2860
Citimortgage, Inc. v. Lehner | 12CA0103-M | foreclosure Civ.R. 60(B) substitute for appeal | Carr | 6/30/2014 | 2014-Ohio-2859
State v. Kaminski | 27112 | Megans Law, Adam Walsh Act, R.C. 2950.09, sex offender classification, reporting requirements | Hensal | 6/30/2014 | 2014-Ohio-2858
State v. Jordan | 27005 | Confrontation Clause, harmless error, Fourth Amendment, inventory search, jury instruction, Crim.R. 7(D), R.C. 2923.03, complicity, sufficiency, manifest weight | Hensal | 6/30/2014 | 2014-Ohio-2857
State v. Johnson | 26914 | obstructing official business, resisting arrest, assault, and driving under financial responsibility law suspension or cancellation | Moore | 6/30/2014 | 2014-Ohio-2856
Huntington Natl. Bank v. Clark | 26950 | jurisdiction, R.C. 2323.13(A), foreclosure | Moore | 6/30/2014 | 2014-Ohio-2855
State v. Henderson | 13CA0039 | post-release control void vacate res judicata original sentence direct appeal guilty plea life sentence Fischer Bloomer | Carr | 6/30/2014 | 2014-Ohio-2854
Hall v. Zambrano | 13CA0047 | due process notice of hearing requirement dog bite liability breach of contract | Whitmore | 6/30/2014 | 2014-Ohio-2853
State v. Carlisle | 27028 | manifest weight, felonious assault | Moore | 6/30/2014 | 2014-Ohio-2852
Bowman v. Bowman | 13CA0064-M | domestic violence civil protection order corporal punishment sufficiency of protection order | Whitmore | 6/30/2014 | 2014-Ohio-2851
Baker v. Bob Evans Farms, Inc. | 13CA0023 | summary judgment open and obvious water accumulation carpet runner slip and fall causation conjecture reasonable inference | Carr | 6/30/2014 | 2014-Ohio-2850
State v. Oden | 27151 | suppress, investigative stop, totality of the circumstances, pat-down search | Moore | 6/25/2014 | 2014-Ohio-2752
Novak v. Giganti | 27063 | open and obvious, invitee, negligence, duty to warn, Civ.R. 56 | Hensal | 6/25/2014 | 2014-Ohio-2751
Bank of Am., N.A. v. Loya | 26973 | foreclosure standing holder note and mortgage personal knowledge HUD regulations | Moore | 6/25/2014 | 2014-Ohio-2750
In re S.R. | 27209 | permanent custody, subject matter jurisdiction of juvenile court, out-of-state service provisions of R.C. 2151/.29, | Carr | 6/25/2014 | 2014-Ohio-2749
In re B.C. | 26976, 26977 | legal custody, App.R. 4(B)(5), child support, In re H.F., R.C. 2151.414(D)(1), R.C. 2151.415(D)(2), six-month extension, Juv.R. 40(D)(3)(b)(iv), R.C. 2151.419(A)(1), R.C. 3119.22, ineffective assistance of counsel | Moore | 6/25/2014 | 2014-Ohio-2748
Havrilla v. Havrilla | 27064 | financial misconduct restore Wife to maiden name offsetting support payments | Whitmore | 6/25/2014 | 2014-Ohio-2747
JPMorgan Chase Bank, Natl. Assn. v. Burden | 27104 | foreclosure - notice of default - applicability of HUD regulations - affiant's personal knowledge | Whitmore | 6/25/2014 | 2014-Ohio-2746
State v. Berg | 26953 | warrantless entry, exigent circumstances, Fourth Amendment, search and seizure, emergency aid exception | Belfance | 6/25/2014 | 2014-Ohio-2745
State v. Dunbarr | 13CA010475 | community control violation notice sentence contrary to law | Whitmore | 6/23/2014 | 2014-Ohio-2723
Clough v. Bilancini | 13CA010399 | judicial immunity, preservation of the record, attorney malpractice | Hensal | 6/23/2014 | 2014-Ohio-2722
State v. Barnes | 13CA010502, 13CA010503 | Failure to register mandatory penalty R.C. 2950.99(A)(2)(b) constitutionality of statute | Whitmore | 6/23/2014 | 2014-Ohio-2721
State v. McGowan | 27092 | presentence investigation report, sentencing, rape | Moore | 6/18/2014 | 2014-Ohio-2630
Huntington Natl. Bank v. Clark | 26883 | jurisdiction, R.C. 2323.13(A) | Moore | 6/18/2014 | 2014-Ohio-2629
State v. Calhoun | 27059 | motion to withdraw plea, Crim.R. 32.1, manifest injustice, evidentiary documents, res judicata | Moore | 6/18/2014 | 2014-Ohio-2628
AKC, Inc. v. ServiceMaster Residential Commercial Servs., Ltd. | 27070 | Forum selection clause choice of law clause Business Opportunity Law R.C. 1334 et seq. | Whitmore | 6/18/2014 | 2014-Ohio-2627
State v. Stover | 13CA0035 | admissibility of prior inconsistent statements impeachment of ones own witness restitution to a third party insurer | Whitmore | 6/16/2014 | 2014-Ohio-2572
State v. Polansky | 13CA0012-M | no contest plea waive sufficiency of indictment sufficiency of evidence | Carr | 6/16/2014 | 2014-Ohio-2571
In re J.G. | 14CA0004 | case plan, adoption plan, permanent custody, termination of parental rights, legal custody, permanency, best interest of the child. | Gallagher | 6/16/2014 | 2014-Ohio-2570
State v. Gasser | 13CA0042 | motion to suppress unreasonable stop community caretaking exception | Carr | 6/16/2014 | 2014-Ohio-2569
Uphouse v. Uphouse | 27057 | stipulation division of marital property agreement spousal support R.C. 3105.171 R.C. 3105.18 | Carr | 6/11/2014 | 2014-Ohio-2514
Lopez v. Thomas | 27115 | defamation libel slander private figure negligent recording overt threat implied threat | Whitmore | 6/11/2014 | 2014-Ohio-2513
State Farm Mut. Ins. Co. v. Jiles | 26841 | R.C. 3109.09 parental liability statute willfully damages property intentional - $10,000 cap legislative intent penalty | Carr | 6/11/2014 | 2014-Ohio-2512
Davis v. Akron | 27014 | immunity road conditions R.C. 723.01 R.C. Chapter 27443 | Carr | 6/11/2014 | 2014-Ohio-2511
State v. Asefi | 26931 | allied offenses of similar import, merger, guilty plea, inquiry into whether offenses should merge, hearing | Belfance | 6/11/2014 | 2014-Ohio-2510
State v. Shaffer | 12CA0071-M, 12CA0077-M | R.C. 2925.041, R.C. 2929.14, H.B. 86 | Moore | 6/9/2014 | 2014-Ohio-2461
Miller v. Bennett | 13CA010336 | motion to dismiss, Civ.R. 12(B)(6); R.C. 1303.47, U.C.C. 3-405 | Hensal | 6/9/2014 | 2014-Ohio-2460
Lubanovich v. McGlocklin | 12CA0090-M | negligence sufficiency damages reasonable certainty | Carr | 6/9/2014 | 2014-Ohio-2459
In re A.S. | 14CA010532, 14CA010534 | permanent custody, best interest, alternate findings under R.C. 2151.414(E), ineffective assistance of trial counsel, | Belfance | 6/9/2014 | 2014-Ohio-2458
State v. Watson | 26777 | felony murder child endangering guilty plea voluntary effect of plea appointed counsel | Moore | 6/4/2014 | 2014-Ohio-2373
Deutsche Bank Natl. Trust Co. v. Reynolds | 27192 | foreclosure Schwartzwald standing current holder note and mortgage servicer affidavit personal knowledge | Hensal | 6/4/2014 | 2014-Ohio-2372
Kessel v. Glenmark Generics, Inc., USA | 26833 | Civ.R. 12(B)(6) matters outside the pleadings | Whitmore | 6/4/2014 | 2014-Ohio-2371
State v. Greer | 26996 | suppress, investigative stop, totality of the circumstances | Moore | 6/4/2014 | 2014-Ohio-2370
State v. Riffe | 13CA010442 | R.C. 2919.25, sufficiency, manifest weight, domestic violence, credibility | Hensal | 6/2/2014 | 2014-Ohio-2334
In re N.R. | 13CA0091-M | Minimum sentence parole violation- juvenile court | Whitmore | 6/2/2014 | 2014-Ohio-2333
In re D.T. | 13CA010451 | adjudication, disposition, final order, interim order under Juv.R. 40, dependency and neglect | Whitmore | 6/2/2014 | 2014-Ohio-2332
State v. Dovala | 13CA010440 | Civ.R. 60(B)(5) extraordinary or unusual circumstances meritorious defense | Whitmore | 6/2/2014 | 2014-Ohio-2331
State v. Partee | 27093 | Harmless Error, Evidence, Crim.R. 52(A), rape, unlawful sexual conduct with a minor, Evid.R. 402, Evid.R. 403(A). | Belfance | 5/28/2014 | 2014-Ohio-2255
Morrison v. Morrison | 27150 | residential parent designation R.C. 3109.04(C) findings record on appeal date for child support obligation | Whitmore | 5/28/2014 | 2014-Ohio-2254
State v. Smith | 13CA0043-M | R.C. 2953.32 expungement application for sealing rehabilitation weigh interests findings prior convictions | Whitmore | 5/27/2014 | 2014-Ohio-2232
State v. Noel | 13CA010359 | R.C. 2929.20(C)(2) state correctional institution judicial release jail prison | Carr | 5/27/2014 | 2014-Ohio-2231
Koprivec v. Railes-to-Trails of Wayne Cty. | 13CA0004 | railroad corridor adverse possession declaratory relief quiet title declaratory judgment final, appealable rights and obligations of the parties | Carr | 5/27/2014 | 2014-Ohio-2230
Capital One Bank v. Jones | 13CA0038-M | realignment, Civ.R. 20, Civ.R. 21, Civ.R. 41(B)(1) | Hensal | 5/27/2014 | 2014-Ohio-2229
State v. Jones | 12CA010262 | rape, importuning, minor, medical testimony, manifest weight, ineffective assistance of counsel, right to present a defense, failure to have witness testify | Belfance | 5/27/2014 | 2014-Ohio-2228
Hoover v. Elyria | 13CA010364 | R.C 2505.04, 2505.07, administrative appeal, jurisdiction, | Belfance | 5/27/2014 | 2014-Ohio-2227
State v. Hartman | 13CA0018-M | post-conviction relief attorney power of attorney authority to practice law Ohio Constitution R.C. 4705.01 | Carr | 5/27/2014 | 2014-Ohio-2226
State v. Thomas | 27090 | arson manifest weight sufficiency | Whitmore | 5/21/2014 | 2014-Ohio-2166
State v. Clayton | 26910 | Firearm specification allied offenses of similar import consecutive sentences | Whitmore | 5/21/2014 | 2014-Ohio-2165
State v. McLemore | 13CA010435 | motion to suppress investigatory detention arrest probable cause transfer to police station discarded sweatshirt | Hensal | 5/19/2014 | 2014-Ohio-2116
Tucker v. Dennis Baughman Co., Ltd. | 26620, 26635 | open and obvious, negligence, jurisdiction, premises liability, staircase | Belfance | 5/14/2014 | 2014-Ohio-2040
Three Dimes Ents., Inc. v. Arwen Inc. | 27145 | promissory note, creditors bill, R.C. 2117.06, Civ.R. 60(B) | Hensal | 5/14/2014 | 2014-Ohio-2039
State v. Ross | 27180 | post-conviction relief Sixth Amendment impartial jury post-trial juror misconduct friend website | Whitmore | 5/14/2014 | 2014-Ohio-2038
Kane v. Kane | 26781 | R.C. 3119.04(B); R.C. 3119.23, combined income over $150,000 | Moore | 5/14/2014 | 2014-Ohio-2037
Akron v. Jackson | 27077 | parking violation magistrates decision objections transcript plain error | Hensal | 5/14/2014 | 2014-Ohio-2036
Wiseman v. Wiseman | 13CA0009-M | separation agreement contract construction ambiguous de novo manifest weight plain error contempt | Carr | 5/12/2014 | 2014-Ohio-2002
State v. Taylor | 13CA010366, 13CA010367, 13CA010368, 13CA010369 | community control record on appeal presentence investigation | Moore | 5/12/2014 | 2014-Ohio-2001
Huntington Natl. Bank v. Patino | 13CA0061-M | Foreclosure failure to preserve issue for appeal | Whitmore | 5/12/2014 | 2014-Ohio-2000
State v. Guyton | 13CA010443 | not raised below, clerical error | Belfance | 5/12/2014 | 2014-Ohio-1999
St. Croix, Ltd. v. Damitz | 26565, 26566 | contract, settlement agreement, interpretation, declaratory judgment | Belfance | 5/7/2014 | 2014-Ohio-1926
State v. Holiman | 27105, 27106 | consecutive sentences escape R.C. 2929.14(C)(2) - required statutory findings R.C. 2929.14(C)(4) | Whitmore | 5/7/2014 | 2014-Ohio-1925
State v. Cunningham | 26744 | anonymous tip, Florida v. J.L., suppression motion | Belfance | 5/7/2014 | 2014-Ohio-1924
State v. Cobb | 26847 | venue, subject matter jurisdiction, guilty plea, ineffective assistance of counsel, right to counsel | Belfance | 5/7/2014 | 2014-Ohio-1923
State v. Washington | 11CA010015 | allied offenses failure to comply obstructing official business high-speed chase foot chase | Whitmore | 5/5/2014 | 2014-Ohio-1876
Riley v. Wayne Mut. Ins. Co. | 27142 | summary judgment fire insurance policy exclusion delivery usual and customary | Belfance | 4/30/2014 | 2014-Ohio-1818

Page: [ 1] 2 3 next